@@ -529,12 +529,12 @@ def tf_events_to_dict(path, type=''):
             if not 'image' in v.tag:
                 if v.tag in log_dict.keys():
                     decoded = tf.compat.v1.decode_raw(v.tensor.tensor_content, tf.float32)
-                    log_dict[v.tag]["step"].append(str(len(log_dict[v.tag]["step"])+1))
-                    log_dict[v.tag]["value"].append(str(tf.cast(decoded, tf.float32).numpy()[0]))
+                    log_dict[v.tag]["steps"].append(str(len(log_dict[v.tag]["step"])+1))
+                    log_dict[v.tag]["values"].append(str(tf.cast(decoded, tf.float32).numpy()[0]))
                 else:
                     decoded = tf.compat.v1.decode_raw(v.tensor.tensor_content, tf.float32)
                     if type=='train':
-                        scalar_dict = {"step": [0], "value": [str(tf.cast(decoded, tf.float32).numpy()[0])]}
+                        scalar_dict = {"steps": [0], "values": [str(tf.cast(decoded, tf.float32).numpy()[0])]}
                         log_dict[v.tag] = scalar_dict
                     if type=='eval':
                         log_dict[v.tag] = str(tf.cast(decoded, tf.float32).numpy()[0])
